@@ -1,4 +1,4 @@
-# Copyright (c) 2010-2019 Emmanuel Blot <emmanuel.blot@free.fr>
+# Copyright (c) 2010-2024 Emmanuel Blot <emmanuel.blot@free.fr>
 # Copyright (c) 2008-2016, Neotion
 # All rights reserved.
 #
@@ -9,11 +9,10 @@
 from typing import Iterable, List, Optional, Tuple, Union
 from .misc import is_iterable, xor
 
-#pylint: disable-msg=invalid-name
-#pylint: disable-msg=unneeded-not
-#pylint: disable-msg=too-many-branches
-#pylint: disable-msg=too-many-arguments
-#pylint: disable-msg=duplicate-key
+# pylint: disable=invalid-name
+# pylint: disable=unneeded-not
+# pylint: disable=duplicate-key
+
 
 class BitSequenceError(Exception):
     """Bit sequence error"""
@@ -72,7 +71,7 @@ class BitSequence:
         elif value is None:
             pass
         else:
-            raise BitSequenceError("Cannot initialize from a %s" % type(value))
+            raise BitSequenceError(f"Cannot initialize from '{type(value)}'")
         self._update_length(length, msb)
 
     def sequence(self) -> bytearray:
@@ -273,7 +272,7 @@ class BitSequence:
             else:
                 j = None
             chunks.append(srepr[-i-8:j])
-        return '%d: %s' % (len(self), ' '.join(reversed(chunks)))
+        return f'{len(self)}: {" ".join(reversed(chunks))}'
 
     def __int__(self):
         value = 0
@@ -372,14 +371,15 @@ class BitZSequence(BitSequence):
         return self
 
     def tobyte(self, msb=False):
-        raise BitSequenceError("Type %s cannot be converted to byte" %
-                               type(self))
+        raise BitSequenceError(f'Type {type(self)} cannot be converted to '
+                               f'byte')
 
     def tobytes(self, msb=False, msby=False):
-        raise BitSequenceError("Type %s cannot be converted to bytes" %
-                               type(self))
+        raise BitSequenceError(f'Type {type(self)} cannot be converted to '
+                               f'bytes')
 
     def matches(self, other):
+        # pylint: disable=missing-function-docstring
         if not isinstance(self, BitSequence):
             raise BitSequenceError('Not a BitSequence instance')
         # the bit sequence should be of the same length
@@ -495,7 +495,7 @@ class BitField:
     def __getitem__(self, index):
         if isinstance(index, slice):
             if index.stop == index.start:
-                return
+                return None
             if index.stop < index.start:
                 offset = index.stop
                 count = index.start-index.stop+1
