@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2020, Emmanuel Blot <emmanuel.blot@free.fr>
+# Copyright (c) 2014-2024, Emmanuel Blot <emmanuel.blot@free.fr>
 # Copyright (c) 2016, Emmanuel Bouaziz <ebouaziz@free.fr>
 # All rights reserved.
 #
@@ -6,7 +6,6 @@
 
 """GPIO/BitBang support for PyFdti"""
 
-#pylint: disable-msg=too-few-public-methods
 
 from struct import calcsize as scalc, unpack as sunpack
 from typing import Iterable, Optional, Tuple, Union
@@ -428,8 +427,8 @@ class GpioMpsseController(GpioBaseController):
 
     MPSSE_PAYLOAD_MAX_LENGTH = 0xFF00  # 16 bits max (- spare for control)
 
-    def read(self, readlen: int = 1, peek: Optional[bool] = None) -> \
-             Union[int, bytes, Tuple[int]]:
+    def read(self, readlen: int = 1, peek: Optional[bool] = None) \
+            -> Union[int, bytes, Tuple[int]]:
         """Read the GPIO input pin electrical level.
 
            :param readlen: how many GPIO samples to retrieve. Each sample if
@@ -481,7 +480,7 @@ class GpioMpsseController(GpioBaseController):
         self._frequency = self._ftdi.set_frequency(float(frequency))
 
     def _update_direction(self) -> None:
-        # nothing to do in MPSSE mode, as direction is udpated with each
+        # nothing to do in MPSSE mode, as direction is updated with each
         # GPIO command
         pass
 
@@ -499,7 +498,7 @@ class GpioMpsseController(GpioBaseController):
     def _read_mpsse(self, count: int) -> Tuple[int]:
         if self._width > 8:
             cmd = bytearray([Ftdi.GET_BITS_LOW, Ftdi.GET_BITS_HIGH] * count)
-            fmt = '<%dH' % count
+            fmt = f'<{count}H'
         else:
             cmd = bytearray([Ftdi.GET_BITS_LOW] * count)
             fmt = None
@@ -510,8 +509,8 @@ class GpioMpsseController(GpioBaseController):
         size = scalc(fmt) if fmt else count
         data = self._ftdi.read_data_bytes(size, 4)
         if len(data) != size:
-            raise FtdiError('Cannot read GPIO, recv %d out of %d bytes' %
-                            (len(data), size))
+            raise FtdiError(f'Cannot read GPIO, recv {len(data)} '
+                            f'out of {size} bytes')
         if fmt:
             return sunpack(fmt, data)
         return data
