@@ -1,21 +1,13 @@
 """PyUSB virtual FTDI device."""
 
-# Copyright (c) 2020-2023, Emmanuel Blot <emmanuel.blot@free.fr>
+# Copyright (c) 2020-2024, Emmanuel Blot <emmanuel.blot@free.fr>
 # All rights reserved.
 #
 # SPDX-License-Identifier: BSD-3-Clause
 
-#pylint: disable-msg=missing-docstring
-#pylint: disable-msg=unused-argument
-#pylint: disable-msg=invalid-name
-#pylint: disable-msg=too-many-arguments
-#pylint: disable-msg=too-many-locals
-#pylint: disable-msg=too-many-branches
-#pylint: disable-msg=too-many-statements
-#pylint: disable-msg=too-many-instance-attributes
-#pylint: disable-msg=too-many-public-methods
-#pylint: disable-msg=too-few-public-methods
-#pylint: disable-msg=no-self-use
+# pylint: disable=missing-docstring
+# pylint: disable=unused-argument
+# pylint: disable=invalid-name
 
 import os
 from array import array
@@ -24,13 +16,15 @@ from collections import deque
 from enum import IntEnum, unique
 from logging import getLogger
 from struct import calcsize as scalc, pack as spack, unpack as sunpack
-from sys import version_info
 from threading import Event, Lock, Thread
 from time import sleep, time as now
-from typing import List, Mapping, NamedTuple, Optional, Sequence, Tuple
+from typing import (TYPE_CHECKING, List, Mapping, NamedTuple, Optional,
+                    Sequence, Tuple)
 from pyftdi.eeprom import FtdiEeprom   # only for consts, do not use code
 from .consts import FTDICONST, USBCONST
 from .mpsse import VirtMpsseEngine, VirtMpsseTracer
+if TYPE_CHECKING:
+    from .backend import VirtDeviceHandle
 
 
 class Pipe:
@@ -211,7 +205,6 @@ class VirtFtdiPort:
         rx: Fifo  # Host-to-FTDI
         tx: Fifo  # FTDI-to-host
 
-
     @unique
     class BitMode(IntEnum):
         """Function mode selection.
@@ -905,10 +898,9 @@ class VirtFtdiPort:
                     else:
                         _wait_delay = self.SLEEP_DELAY
                     continue
-                else:
-                    self.log.error('Unimplemented support for command %d',
-                                   command)
-                    continue
+                self.log.error('Unimplemented support for command %d',
+                               command)
+                continue
             self.log.debug('End of worker %s', self._tx_thread.name)
         except Exception as exc:
             self.log.error('Dead of worker %s: %s', self._tx_thread.name, exc)
